@@ -13,14 +13,14 @@ add.markers <- function(gpData,geno,map=NULL){
   if(is.null(colnames(geno)) & !is.null(map))
     if(ncol(geno) == nrow(map)) colnames(geno) <- rownames(map) else
       stop("Check the colnames of", substitute(geno), " and the rownames of ", substitute(map), "!")
-  
+
   # merge genotypic data
   nmiss <- sum(!rownames(gpData$geno) %in% rownames(geno))
   if(nmiss > 0){
     geno <- rbind(matrix(NA, nrow = nmiss, ncol = ncol(geno)), geno)
     rownames(geno)[1:nmiss] <- rownames(gpData$geno)[!rownames(gpData$geno) %in% rownames(geno)]
   }
-  geno <- geno[match(rownames(gpData$geno), rownames(geno)), ] 
+  geno <- geno[match(rownames(gpData$geno), rownames(geno)), ]
   gpData$geno <- cbind(gpData$geno,geno)
   # first column as rownames and delete first column
   # merge map
@@ -57,7 +57,7 @@ add.individuals <- function(gpData,pheno=NULL,geno=NULL,pedigree=NULL,covar=NULL
           any(pheno$ID %in% gpData$covar$id)){
         stop("some of the individuals of are already in ", substitute(gpData))
       }
-      if(is.null(repl)) repl <- "repl" 
+      if(is.null(repl)) repl <- "repl"
       else if(!all(unique(pheno[, repl]) %in% dimnames(gpData$pheno)[[3]])) stop("Your values for replication is not in the dimnames of ", substitute(gpData$pheno))
       colnames(pheno)[colnames(pheno) == repl] <- "repl"
       # merge phenotypic data
@@ -67,8 +67,10 @@ add.individuals <- function(gpData,pheno=NULL,geno=NULL,pedigree=NULL,covar=NULL
       } else {
         if(!"ID" %in% colnames(pheno))  stop("In", substitute(pheno), "the columns 'ID' and/or 'repl' are/is missing!")
       }
-      if(!is.null(pheno)) if(any(colnames(pheno)[colnames(pheno)!="ID"]!=dimnames(gpData$pheno)[[2]])) stop("different phenotypes (colnames) in '", substitute(gpData$pheno), "' and '", substitute(pheno), "'")
-      if(!is.null(pheno)) if(any(colnames(pheno)[colnames(pheno)!="ID"]!=dimnames(gpData$phenoCovars)[[2]])) stop("different phenotypes (colnames) in '", substitute(gpData$pheno), "' and '", substitute(pheno), "'")
+      if(!is.null(pheno))
+        if(!all(!colnames(pheno)[colnames(pheno)!="ID"]%in%dimnames(gpData$pheno)[[2]] |
+                !colnames(pheno)[colnames(pheno)!="ID"]%in%dimnames(gpData$phenoCovars)[[2]]))
+          stop("different phenotypes (colnames) in '", substitute(gpData$pheno), "' or '",  substitute(gpData$phenoCovar),"' and '", substitute(pheno), "'")
       df.pheno <- gpData2data.frame(gpData, onlyPheno=TRUE, trait = dimnames(gpData$pheno)[[2]])
       if(!all(colnames(df.pheno) %in% colnames(pheno))) warning("Not all traits and covariates are available in the new data!")
       pheno[, colnames(df.pheno)[!colnames(df.pheno) %in% colnames(pheno)]] <- NA
@@ -82,23 +84,23 @@ add.individuals <- function(gpData,pheno=NULL,geno=NULL,pedigree=NULL,covar=NULL
       # merge genotypic data
       if(!is.null(geno)) if(any(colnames(geno)!=colnames(gpData$geno))) stop("different markers (colnames) in 'gpData$geno' and 'geno'")
       geno <- rbind(gpData$geno,geno)
-      
+
       # merge pedigree
       pedigree <- rbind(gpData$pedigree,pedigree)
       # reorder if necessary
       if(!is.null(pedigree)) pedigree <- orderBy(~gener,pedigree)
-      
+
       # merge covar  (not with first columns)
-      
+
       if(any(colnames(covar) %in% c("genotyped","phenotyped","id"))) stop("not specify columns 'genotyped','phenotyped' and 'id' in 'covar' ")
       if(!is.null(covar)){
         cc <- data.frame(gpData$covar[,!colnames(gpData$covar) %in% c("genotyped","phenotyped","id")])
         rownames(cc) <- rownames(gpData$covar)
         colnames(cc) <- colnames(gpData$covar)[!colnames(gpData$covar) %in% c("genotyped","phenotyped","id")]
-        covarUpdate <- rbind(cc,covar) 
-      }  
+        covarUpdate <- rbind(cc,covar)
+      }
       else covarUpdate <- gpData$covar
-      
+
       # need id in rownames for create.gpData
       rownames(covarUpdate) <- c(as.character(gpData$covar$id),rownames(covar))
 
